MediaStreamTrack class abstract

Constructors

MediaStreamTrack()

Properties

enabled ↔ bool
Returns the enable state of MediaStreamTrack
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String?
Returns the unique identifier of the track
no setter
kind → String?
Returns the string 'audio' if this object represents an audio track or 'video' if this object represents a video track.
no setter
label → String?
This may label audio and video sources (e.g., "Internal microphone" or "External USB Webcam").
no setter
muted → bool?
Returns true if the track is muted, and false otherwise.
no setter
onEnded ↔ StreamTrackCallback?
Callback foronended event
getter/setter pair
onMute ↔ StreamTrackCallback?
Callback for onmute event
getter/setter pair
onUnMute ↔ StreamTrackCallback?
Callback for unmute event
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

adaptRes(int width, int height) → Future<void>
applyConstraints([Map<String, dynamic>? constraints]) → Future<void>
Applies a set of constraints to the track.
captureFrame() → Future<ByteBuffer>
clone() → Future<MediaStreamTrack>
dispose() → Future<void>
enableSpeakerphone(bool enable) → void
getConstraints() → Map<String, dynamic>
Returns a map containing the set of constraints most recently established for the track using a prior call to applyConstraints().
getSettings() → Map<String, dynamic>
hasTorch() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTorch(bool torch) → Future<void>
stop() → Future<void>
switchCamera() → Future<bool>
Throws error if switching camera failed
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited