menu
huddle01_flutter_client package
documentation
huddle_client.dart
RTCRtpEncoding
active property
active property
dark_mode
light_mode
active
property
bool
active
getter/setter pair
Set to true to cause this encoding to be sent, and false for it not to be sent.
Implementation
bool active;
huddle01_flutter_client package
documentation
huddle_client
RTCRtpEncoding
active property
RTCRtpEncoding class